@@ -1,20 +1,16 @@
-# encoding: utf-8
-
-from __future__ import absolute_import, division, print_function, unicode_literals
-
 from django import template
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import six
 
 from haystack.utils import importlib
 
-
 register = template.Library()
 
 
 class HighlightNode(template.Node):
-    def __init__(self, text_block, query, html_tag=None, css_class=None, max_length=None):
+    def __init__(
+        self, text_block, query, html_tag=None, css_class=None, max_length=None
+    ):
         self.text_block = template.Variable(text_block)
         self.query = template.Variable(query)
         self.html_tag = html_tag
@@ -36,26 +32,36 @@ class HighlightNode(template.Node):
         kwargs = {}
 
         if self.html_tag is not None:
-            kwargs['html_tag'] = self.html_tag.resolve(context)
+            kwargs["html_tag"] = self.html_tag.resolve(context)
 
         if self.css_class is not None:
-            kwargs['css_class'] = self.css_class.resolve(context)
+            kwargs["css_class"] = self.css_class.resolve(context)
 
         if self.max_length is not None:
-            kwargs['max_length'] = self.max_length.resolve(context)
+            kwargs["max_length"] = self.max_length.resolve(context)
 
         # Handle a user-defined highlighting function.
-        if hasattr(settings, 'HAYSTACK_CUSTOM_HIGHLIGHTER') and settings.HAYSTACK_CUSTOM_HIGHLIGHTER:
+        if (
+            hasattr(settings, "HAYSTACK_CUSTOM_HIGHLIGHTER")
+            and settings.HAYSTACK_CUSTOM_HIGHLIGHTER
+        ):
             # Do the import dance.
             try:
-                path_bits = settings.HAYSTACK_CUSTOM_HIGHLIGHTER.split('.')
-                highlighter_path, highlighter_classname = '.'.join(path_bits[:-1]), path_bits[-1]
+                path_bits = settings.HAYSTACK_CUSTOM_HIGHLIGHTER.split(".")
+                highlighter_path, highlighter_classname = (
+                    ".".join(path_bits[:-1]),
+                    path_bits[-1],
+                )
                 highlighter_module = importlib.import_module(highlighter_path)
                 highlighter_class = getattr(highlighter_module, highlighter_classname)
             except (ImportError, AttributeError) as e:
-                raise ImproperlyConfigured("The highlighter '%s' could not be imported: %s" % (settings.HAYSTACK_CUSTOM_HIGHLIGHTER, e))
+                raise ImproperlyConfigured(
+                    "The highlighter '%s' could not be imported: %s"
+                    % (settings.HAYSTACK_CUSTOM_HIGHLIGHTER, e)
+                )
         else:
             from haystack.utils.highlighting import Highlighter
+
             highlighter_class = Highlighter
 
         highlighter = highlighter_class(query, **kwargs)
@@ -91,15 +97,21 @@ def highlight(parser, token):
     tag_name = bits[0]
 
     if not len(bits) % 2 == 0:
-        raise template.TemplateSyntaxError(u"'%s' tag requires valid pairings arguments." % tag_name)
+        raise template.TemplateSyntaxError(
+            "'%s' tag requires valid pairings arguments." % tag_name
+        )
 
     text_block = bits[1]
 
     if len(bits) < 4:
-        raise template.TemplateSyntaxError(u"'%s' tag requires an object and a query provided by 'with'." % tag_name)
+        raise template.TemplateSyntaxError(
+            "'%s' tag requires an object and a query provided by 'with'." % tag_name
+        )
 
-    if bits[2] != 'with':
-        raise template.TemplateSyntaxError(u"'%s' tag's second argument should be 'with'." % tag_name)
+    if bits[2] != "with":
+        raise template.TemplateSyntaxError(
+            "'%s' tag's second argument should be 'with'." % tag_name
+        )
 
     query = bits[3]
 
@@ -107,13 +119,13 @@ def highlight(parser, token):
     kwargs = {}
 
     for bit in arg_bits:
-        if bit == 'css_class':
-            kwargs['css_class'] = six.next(arg_bits)
+        if bit == "css_class":
+            kwargs["css_class"] = next(arg_bits)
 
-        if bit == 'html_tag':
-            kwargs['html_tag'] = six.next(arg_bits)
+        if bit == "html_tag":
+            kwargs["html_tag"] = next(arg_bits)
 
-        if bit == 'max_length':
-            kwargs['max_length'] = six.next(arg_bits)
+        if bit == "max_length":
+            kwargs["max_length"] = next(arg_bits)
 
     return HighlightNode(text_block, query, **kwargs)
