@@ -1,4 +1,3 @@
-# encoding: utf-8
 from django.conf import settings
 from django.core.paginator import InvalidPage, Paginator
 from django.http import Http404
@@ -10,7 +9,7 @@ from haystack.query import EmptySearchQuerySet
 RESULTS_PER_PAGE = getattr(settings, "HAYSTACK_SEARCH_RESULTS_PER_PAGE", 20)
 
 
-class SearchView(object):
+class SearchView:
     template = "search/search.html"
     extra_context = {}
     query = ""
@@ -170,7 +169,7 @@ class FacetedSearchView(SearchView):
         if kwargs.get("form_class") is None:
             kwargs["form_class"] = FacetedSearchForm
 
-        super(FacetedSearchView, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     def build_form(self, form_kwargs=None):
         if form_kwargs is None:
@@ -180,10 +179,10 @@ class FacetedSearchView(SearchView):
         # facet expressions:
         form_kwargs["selected_facets"] = self.request.GET.getlist("selected_facets")
 
-        return super(FacetedSearchView, self).build_form(form_kwargs)
+        return super().build_form(form_kwargs)
 
     def extra_context(self):
-        extra = super(FacetedSearchView, self).extra_context()
+        extra = super().extra_context()
         extra["request"] = self.request
         extra["facets"] = self.results.facet_counts()
         return extra
