@@ -5,10 +5,8 @@ from haystack.admin import SearchModelAdmin
 from .models import MockModel
 
 
+@admin.register(MockModel)
 class MockModelAdmin(SearchModelAdmin):
     haystack_connection = "solr"
     date_hierarchy = "pub_date"
     list_display = ("author", "pub_date")
-
-
-admin.site.register(MockModel, MockModelAdmin)
